From ec674fed06a9068dbc881e9a222efb33477f30af Mon Sep 17 00:00:00 2001
From: Jerome Charaoui <jerome@riseup.net>
Date: Fri, 7 Feb 2014 11:56:39 -0500
Subject: [PATCH] Obsess over processing errors

---
 scanner/PhotoAlbum.py | 12 ++++++++++--
 scanner/TreeWalker.py | 11 +++++++++--
 2 files changed, 19 insertions(+), 4 deletions(-)

diff --git a/scanner/PhotoAlbum.py b/scanner/PhotoAlbum.py
index aeb3087..f5124fc 100644
--- a/scanner/PhotoAlbum.py
+++ b/scanner/PhotoAlbum.py
@@ -14,6 +14,7 @@ class Album(object):
 		self._albums = list()
 		self._photos_sorted = True
 		self._albums_sorted = True
+		self._full_cache = True
 	@property
 	def photos(self):
 		return self._photos
@@ -23,6 +24,12 @@ class Album(object):
 	@property
 	def path(self):
 		return self._path
+	@property
+	def full_cache(self):
+		return self._full_cache
+	@full_cache.setter
+	def full_cache(self, value):
+		self._full_cache = value
 	def __str__(self):
 		return self.path
 	@property
@@ -83,6 +90,7 @@ class Album(object):
 		if not cripple:
 			for subalbum in dictionary["albums"]:
 				album.add_album(Album.from_dict(subalbum), cripple)
+		album.full_cache = dictionary["fullCache"]
 		album._sort()
 		return album
 	def to_dict(self, cripple=True):
@@ -91,12 +99,12 @@ class Album(object):
 		if cripple:
 			for sub in self._albums:
 				if not sub.empty:
-					subalbums.append({ "path": trim_base_custom(sub.path, self._path), "date": sub.date })
+					subalbums.append({ "path": trim_base_custom(sub.path, self._path), "date": sub.date, "fullCache": self.full_cache })
 		else:
 			for sub in self._albums:
 				if not sub.empty:
 					subalbums.append(sub)
-		return { "path": self.path, "date": self.date, "albums": subalbums, "photos": self._photos }
+		return { "path": self.path, "date": self.date, "fullCache": self.full_cache, "albums": subalbums, "photos": self._photos }
 	def photo_from_path(self, path):
 		for photo in self._photos:
 			if trim_base(path) == photo._path:
diff --git a/scanner/TreeWalker.py b/scanner/TreeWalker.py
index c2dbd53..5790a85 100644
--- a/scanner/TreeWalker.py
+++ b/scanner/TreeWalker.py
@@ -8,6 +8,7 @@ import json
 
 class TreeWalker:
 	def __init__(self, album_path, cache_path):
+		self.invalid = []
 		self.album_path = os.path.abspath(album_path).decode(sys.getfilesystemencoding())
 		self.cache_path = os.path.abspath(cache_path).decode(sys.getfilesystemencoding())
 		set_cache_path_base(self.album_path)
@@ -16,7 +17,11 @@ class TreeWalker:
 		self.walk(self.album_path)
 		self.big_lists()
 		self.remove_stale()
-		message("complete", "")
+		if len(self.invalid):
+			for i in self.invalid:
+				message("processing failed", i)
+		else:
+			message("complete", "")
 	def walk(self, path):
 		next_level()
 		message("walking", os.path.basename(path))
@@ -26,7 +31,7 @@ class TreeWalker:
 		if os.path.exists(cache):
 			try:
 				cached_album = Album.from_cache(cache)
-				if file_mtime(path) <= file_mtime(cache):
+				if file_mtime(path) <= file_mtime(cache) and cached_album.full_cache:
 					message("full cache", os.path.basename(path))
 					cached = True
 					album = cached_album
@@ -69,6 +74,8 @@ class TreeWalker:
 					self.all_photos.append(photo)
 					album.add_photo(photo)
 				else:
+					self.invalid.append(entry)
+					album.full_cache = False
 					message("unreadable", os.path.basename(entry))
 				back_level()
 		if not album.empty:
-- 
1.8.5.3

